# Progress Update Template

Use this to update progress on implementation plans and tasks.

```markdown
## Progress: [Date]

### Completed Today
- [Specific item completed]
- [Specific item completed]

### In Progress
- [Current work item and status]

### Next Steps
1. [Next action]
2. [Next action]

### Blockers
- [Blocker description] or None

### Notes
[Additional context, decisions made, issues encountered]
```

